@@ -43,9 +43,9 @@ loadinitrd=load mmc ${mmcdev}:${mmcpart} ${initrd_addr} ${snappy_ab}/${initrd_fi
 loadfdt=load mmc ${mmcdev}:${mmcpart} ${fdtaddr} ${snappy_ab}/dtbs/${fdtfile}
 
 # standard kernel and initrd file names; NB: fdtfile is set early from bootcmd
-kernel_file=vmlinuz
-initrd_file=initrd.img
-{{ . }}
+kernel_file={{ .Kernel }}
+initrd_file={{ .Initrd }}
+{{ .Fdt }}
 
 # extra kernel cmdline args, set via mmcroot
 snappy_cmdline=init=/lib/systemd/systemd ro panic=-1 fixrtc
@@ -66,13 +66,14 @@ type FlashInstructions struct {
 	Bootloader []string `yaml:"bootloader"`
 }
 
-func NewCoreUBootImage(location string, size int64, hw HardwareDescription, oem OemDescription) *CoreUBootImage {
+func NewCoreUBootImage(location string, size int64, rootSize int, hw HardwareDescription, oem OemDescription) *CoreUBootImage {
 	return &CoreUBootImage{
 		BaseImage{
 			hardware:  hw,
 			oem:       oem,
 			location:  location,
 			size:      size,
+			rootSize:  rootSize,
 			partCount: 4,
 		},
 	}
@@ -101,69 +102,23 @@ func (img *CoreUBootImage) Partition() error {
 	return parted.create(img.location)
 }
 
-func (img CoreUBootImage) SetupBoot(oemRootPath string) error {
+func (img CoreUBootImage) SetupBoot() error {
 	// destinations
 	bootPath := filepath.Join(img.baseMount, string(bootDir))
-	bootAPath := filepath.Join(bootPath, "a")
-	bootBPath := filepath.Join(bootPath, "b")
-	bootuEnvPath := filepath.Join(bootPath, "uEnv.txt")
 	bootSnappySystemPath := filepath.Join(bootPath, "snappy-system.txt")
 
-	// origins
-	hardwareYamlPath := filepath.Join(img.baseMount, "hardware.yaml")
-	kernelPath := filepath.Join(img.baseMount, img.hardware.Kernel)
-	initrdPath := filepath.Join(img.baseMount, img.hardware.Initrd)
-
-	if err := os.MkdirAll(bootBPath, 0755); err != nil {
+	if err := img.GenericBootSetup(bootPath); err != nil {
 		return err
 	}
 
 	// populate both A/B
-	for _, path := range []string{bootAPath, bootBPath} {
-		if err := os.MkdirAll(path, 0755); err != nil {
-			return err
-		}
-
-		if err := sysutils.CopyFile(hardwareYamlPath, filepath.Join(path, "hardware.yaml")); err != nil {
-			return err
-		}
-
-		if err := sysutils.CopyFile(kernelPath, filepath.Join(path, filepath.Base(kernelPath))); err != nil {
-			return err
-		}
-
-		if err := sysutils.CopyFile(initrdPath, filepath.Join(path, filepath.Base(initrdPath))); err != nil {
-			return err
-		}
-
-		// create layout
-		bootDtbPath := filepath.Join(path, "dtbs")
-		if err := os.MkdirAll(bootDtbPath, 0755); err != nil {
-			return err
-		}
-
+	for _, part := range img.oem.SystemParts() {
+		bootDtbPath := filepath.Join(bootPath, part, "dtbs")
 		if err := img.provisionDtbs(bootDtbPath); err != nil {
 			return err
 		}
 	}
 
-	// if the oem package provides BootAssets use it directly, if not
-	// provisionUenv for backwards compatibility.
-	if bootAssets := img.oem.OEM.Hardware.BootAssets; bootAssets != nil {
-		if err := setupBootAssetFiles(bootPath, oemRootPath, bootAssets.Files); err != nil {
-			return err
-		}
-	} else {
-		if err := img.provisionUenv(bootuEnvPath); err != nil {
-			return err
-		}
-	}
-
-	// create /boot/uboot
-	if err := os.MkdirAll(filepath.Join(img.System(), "boot", "uboot"), 0755); err != nil {
-		return err
-	}
-
 	snappySystemFile, err := os.Create(bootSnappySystemPath)
 	if err != nil {
 		return err
@@ -175,39 +130,12 @@ func (img CoreUBootImage) SetupBoot(oemRootPath string) error {
 		fdtfile = fmt.Sprintf("fdtfile=%s.dtb", platform)
 	}
 
+	templateData := struct{ Fdt, Kernel, Initrd string }{
+		Fdt: fdtfile, Kernel: kernelFileName, Initrd: initrdFileName,
+	}
+
 	t := template.Must(template.New("snappy-system").Parse(snappySystemTemplate))
-	t.Execute(snappySystemFile, fdtfile)
-
-	return nil
-}
-
-func (img CoreUBootImage) provisionUenv(bootuEnvPath string) error {
-	platform := img.oem.Platform()
-
-	if platform != "" {
-		printOut("No platform select, not searching for uEnv.txt")
-		return nil
-	}
-
-	flashAssetsPath := filepath.Join(img.baseMount, "flashtool-assets", platform)
-	uEnvPath := filepath.Join(flashAssetsPath, "uEnv.txt")
-
-	if _, err := os.Stat(flashAssetsPath); os.IsNotExist(err) {
-		printOut("No flash assets path available")
-		return nil
-	} else if err != nil {
-		return err
-	}
-
-	// if a uEnv.txt is provided in the flashtool-assets, use it
-	if _, err := os.Stat(uEnvPath); err == nil {
-		printOut("Adding uEnv.txt to", bootuEnvPath)
-		if err := sysutils.CopyFile(uEnvPath, bootuEnvPath); err != nil {
-			return err
-		}
-	} else {
-		printOut("Can't copy", uEnvPath, "to", bootuEnvPath, "due to:", err)
-	}
+	t.Execute(snappySystemFile, templateData)
 
 	return nil
 }
@@ -226,17 +154,21 @@ func (img CoreUBootImage) provisionDtbs(bootDtbPath string) error {
 		return err
 	}
 
+	if err := os.MkdirAll(bootDtbPath, 0755); err != nil {
+		return err
+	}
+
 	dtb := filepath.Join(dtbsPath, fmt.Sprintf("%s.dtb", img.oem.Platform()))
 
 	// if there is a specific dtb for the platform, copy it.
 	// First look in oem and then in device.
 	if oemDtb := img.oem.OEM.Hardware.Dtb; oemDtb != "" && img.oem.Platform() != "" {
-		oemInstallPath, err := img.oem.InstallPath(img.System())
+		oemRoot, err := img.oem.InstallPath()
 		if err != nil {
 			return err
 		}
 
-		oemDtb := filepath.Join(oemInstallPath, oemDtb)
+		oemDtb := filepath.Join(oemRoot, oemDtb)
 		dst := filepath.Join(bootDtbPath, filepath.Base(dtb))
 		if err := sysutils.CopyFile(oemDtb, dst); err != nil {
 			return err
@@ -258,13 +190,3 @@ func (img CoreUBootImage) provisionDtbs(bootDtbPath string) error {
 
 	return nil
 }
-
-func (img *CoreUBootImage) FlashExtra(oemRootPath, devicePart string) error {
-	// if the oem package has bootloader assets use this and skip the
-	// deprecated device part setup
-	if bootAssets := img.oem.OEM.Hardware.BootAssets; bootAssets != nil {
-		return setupBootAssetRawFiles(img.location, oemRootPath, bootAssets.RawFiles)
-	}
-
-	return nil
-}
