@@ -17,6 +17,8 @@ import (
 	"path/filepath"
 	"strings"
 	"time"
+
+	"launchpad.net/snappy/helpers"
 )
 
 // This program is free software: you can redistribute it and/or modify it
@@ -100,6 +102,12 @@ func (coreCmd *CoreCmd) setupOemConfigs() error {
 		return err
 	}
 
+	// first we need to copy all the files in modprobe.d
+	systemModprobeDir := filepath.Join(coreCmd.img.System(), "etc", "modprobe.d")
+	if err := helpers.RSyncWithDelete(systemModprobeDir, modprobeDir); err != nil {
+		return err
+	}
+
 	modprobeD := filepath.Join(modprobeDir, "ubuntu-core.conf")
 	modprobeDFile, err := os.Create(modprobeD)
 	if err != nil {
